<article class="typography w-full">
    {% if page.meta.title %}
    <h1 class="tracking-tight">{{ page.meta.title }}</h1>
    {% endif %}
    {% if page.meta.summary %}
    <p class="summary">
        {{ page.meta.summary }}
    </p>
    {% endif %}
    {{ page.content }}
</article>